@@ -10,12 +10,16 @@ import sys
 
 from contextlib import contextmanager
 
-__version__ = '0.12.3'
+__version__ = '0.13.2'
 
 from IPython import get_ipython
 from IPython.core.debugger import BdbQuit_excepthook
 from IPython.terminal.ipapp import TerminalIPythonApp
 from IPython.terminal.embed import InteractiveShellEmbed
+try:
+    import configparser
+except:
+    import ConfigParser as configparser
 
 
 shell = get_ipython()
@@ -60,8 +64,12 @@ def wrap_sys_excepthook():
         sys.excepthook = BdbQuit_excepthook
 
 
-def set_trace(frame=None, context=3):
+def set_trace(frame=None, context=None):
     wrap_sys_excepthook()
+    if not context:
+        context = os.environ.get(
+            "IPDB_CONTEXT_SIZE", get_context_from_config()
+        )
     if frame is None:
         frame = sys._getframe().f_back
     p = _init_pdb(context).set_trace(frame)
@@ -69,6 +77,105 @@ def set_trace(frame=None, context=3):
         p.shell.restore_sys_module_state()
 
 
+def get_context_from_config():
+    try:
+        parser = get_config()
+        return parser.getint("ipdb", "context")
+    except (configparser.NoSectionError, configparser.NoOptionError):
+        return 3
+    except ValueError:
+        value = parser.get("ipdb", "context")
+        raise ValueError(
+            "In %s,  context value [%s] cannot be converted into an integer."
+            % (parser.filepath, value)
+        )
+
+
+class ConfigFile(object):
+    """
+    Filehandle wrapper that adds a "[ipdb]" section to the start of a config
+    file so that users don't actually have to manually add a [ipdb] section.
+    Works with configparser versions from both Python 2 and 3
+    """
+
+    def __init__(self, filepath):
+        self.first = True
+        with open(filepath) as f:
+            self.lines = f.readlines()
+
+    # Python 2.7 (Older dot versions)
+    def readline(self):
+        try:
+            return self.__next__()
+        except StopIteration:
+            return ''
+
+    # Python 2.7 (Newer dot versions)
+    def next(self):
+        return self.__next__()
+
+    # Python 3
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        if self.first:
+            self.first = False
+            return "[ipdb]\n"
+        if self.lines:
+            return self.lines.pop(0)
+        raise StopIteration
+
+
+def get_config():
+    """
+    Get ipdb config file settings.
+    All available config files are read.  If settings are in multiple configs,
+    the last value encountered wins.  Values specified on the command-line take
+    precedence over all config file settings.
+    Returns: A ConfigParser object.
+    """
+    parser = configparser.ConfigParser()
+
+    filepaths = []
+
+    # Low priority goes first in the list
+    for cfg_file in ("setup.cfg", ".ipdb"):
+        cwd_filepath = os.path.join(os.getcwd(), cfg_file)
+        if os.path.isfile(cwd_filepath):
+            filepaths.append(cwd_filepath)
+
+    # Medium priority (whenever user wants to set a specific path to config file)
+    home = os.getenv("HOME")
+    if home:
+        default_filepath = os.path.join(home, ".ipdb")
+        if os.path.isfile(default_filepath):
+            filepaths.append(default_filepath)
+
+    # High priority (default files)
+    env_filepath = os.getenv("IPDB_CONFIG")
+    if env_filepath and os.path.isfile(env_filepath):
+        filepaths.append(env_filepath)
+
+    if filepaths:
+        # Python 3 has parser.read_file(iterator) while Python2 has
+        # parser.readfp(obj_with_readline)
+        try:
+            read_func = parser.read_file
+        except AttributeError:
+            read_func = parser.readfp
+        for filepath in filepaths:
+            parser.filepath = filepath
+            # Users are expected to put an [ipdb] section
+            # only if they use setup.cfg
+            if filepath.endswith('setup.cfg'):
+                with open(filepath) as f:
+                    read_func(f)
+            else:
+                read_func(ConfigFile(filepath))
+    return parser
+
+
 def post_mortem(tb=None):
     wrap_sys_excepthook()
     p = _init_pdb()
